@@ -23,7 +23,7 @@ from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
                                     ReadonlyTableVariable, FieldValue,
                                     VariableInterface)
 from calculate.lib.utils.common import getValueFromConfig
-from calculate.lib.variables.user import VariableUrLogin
+from calculate.lib.variables import user
 from calculate.lib.utils.files import (readLinesFile, process,
                                        listDirectory)
 from calculate.desktop._cl_keys import getKey
@@ -305,7 +305,7 @@ class VariableClDesktopOnlineCount(FieldValue, ReadonlyVariable):
     column = 4
 
 
-class VariableClDesktopLogin(VariableUrLogin):
+class VariableClDesktopLogin(user.VariableUrLogin):
     """
     User Login
     """
@@ -315,7 +315,7 @@ class VariableClDesktopLogin(VariableUrLogin):
         if self.Get('cl_action') == 'logout':
             return self.Get('cl_desktop_online_user')
         else:
-            return VariableUrLogin.choice(self)
+            return user.VariableUrLogin.choice(self)
 
     def check(self, value):
         """Does user exist"""
